@@ -29,7 +29,7 @@ struct Magick_PathSmoothQuadraticCurvetoAbs_Wrapper: Magick::PathSmoothQuadratic
 
 void __PathSmoothQuadraticCurvetoAbs()
 {
-    class_< Magick::PathSmoothQuadraticCurvetoAbs, Magick_PathSmoothQuadraticCurvetoAbs_Wrapper >("PathSmoothQuadraticCurvetoAbs", init< const Magick::Coordinate& >())
+    class_< Magick::PathSmoothQuadraticCurvetoAbs, bases<Magick::VPathBase>, Magick_PathSmoothQuadraticCurvetoAbs_Wrapper >("PathSmoothQuadraticCurvetoAbs", init< const Magick::Coordinate& >())
         .def(init< const Magick::CoordinateList& >())
         .def(init< const Magick::PathSmoothQuadraticCurvetoAbs& >())
     ;
