@@ -2,9 +2,14 @@ import unittest
 import sys
 sys.path.append('../')
 sys.path.append('./')
+import pgmagick
 from pgmagick.api import Image, Draw
 
 
+print(pgmagick.gminfo().version)
+libgm_version = [int(v) for v in pgmagick.gminfo().version.split('.')]
+
+
 class ImageTestCase(unittest.TestCase):
 
     def setUp(self):
@@ -23,13 +28,13 @@ class ImageTestCase(unittest.TestCase):
             img.write(unicode('unicode.jpg'))
 
     def test_nonarg(self):
-        im = Image()
+        Image()
 
     def test_arg(self):
-        im = Image((600, 400), 'red')
+        Image((600, 400), 'red')
 
     def test_arg_float(self):
-        im = Image((600.5, 400.4), 'red')
+        Image((600.5, 400.4), 'red')
 
     def test_blur(self):
         self.img.blur(2, 2.3)
@@ -336,6 +341,7 @@ class DrawTestCase(unittest.TestCase):
         self.im.draw(self.d)
         self.im.write('t.png')
 
+    @unittest.skipIf(libgm_version <= [1, 3, 12], "bug in gm version: %s" % str(libgm_version))
     def test_stroke_linejoin(self):
         self.d.stroke_color('lime')
         self.d.stroke_linejoin('round')
